aboutsummaryrefslogtreecommitdiffstats
path: root/calendar/gui/dialogs/comp-editor-page.h
diff options
context:
space:
mode:
authorJP Rosevear <jpr@src.gnome.org>2003-11-07 13:52:24 +0800
committerJP Rosevear <jpr@src.gnome.org>2003-11-07 13:52:24 +0800
commit200606f92810d3de322e5ee96f8326e1a656f8bb (patch)
treeda0dc27f5311128dcb6e7eb6400931e45743372e /calendar/gui/dialogs/comp-editor-page.h
parente5472b4cc9a4bb80b89437a16f8b77943ea35555 (diff)
downloadgsoc2013-evolution-200606f92810d3de322e5ee96f8326e1a656f8bb.tar
gsoc2013-evolution-200606f92810d3de322e5ee96f8326e1a656f8bb.tar.gz
gsoc2013-evolution-200606f92810d3de322e5ee96f8326e1a656f8bb.tar.bz2
gsoc2013-evolution-200606f92810d3de322e5ee96f8326e1a656f8bb.tar.lz
gsoc2013-evolution-200606f92810d3de322e5ee96f8326e1a656f8bb.tar.xz
gsoc2013-evolution-200606f92810d3de322e5ee96f8326e1a656f8bb.tar.zst
gsoc2013-evolution-200606f92810d3de322e5ee96f8326e1a656f8bb.zip
Various changes to merge in evolution-data-server reliance.
svn path=/trunk/; revision=23206
Diffstat (limited to 'calendar/gui/dialogs/comp-editor-page.h')
-rw-r--r--calendar/gui/dialogs/comp-editor-page.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/calendar/gui/dialogs/comp-editor-page.h b/calendar/gui/dialogs/comp-editor-page.h
index e3d4535391..6046a7c039 100644
--- a/calendar/gui/dialogs/comp-editor-page.h
+++ b/calendar/gui/dialogs/comp-editor-page.h
@@ -23,8 +23,8 @@
#include <time.h>
#include <gtk/gtkwidget.h>
-#include <cal-util/cal-component.h>
-#include "cal-client.h"
+#include <libecal/e-cal-component.h>
+#include <libecal/e-cal.h>
G_BEGIN_DECLS
@@ -37,17 +37,17 @@ G_BEGIN_DECLS
#define IS_COMP_EDITOR_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((obj), TYPE_COMP_EDITOR_PAGE))
typedef struct {
- CalComponentDateTime *start;
- CalComponentDateTime *end;
- CalComponentDateTime *due;
+ ECalComponentDateTime *start;
+ ECalComponentDateTime *end;
+ ECalComponentDateTime *due;
struct icaltimetype *complete;
} CompEditorPageDates;
typedef struct {
GtkObject object;
- /* Some of the pages need the CalClient to access timezone data. */
- CalClient *client;
+ /* Some of the pages need the ECal to access timezone data. */
+ ECal *client;
/* The GtkAccelGroup for the page. We install this when the page is
mapped, and uninstall when it is unmapped. libglade would do this
@@ -72,8 +72,8 @@ typedef struct {
GtkWidget *(* get_widget) (CompEditorPage *page);
void (* focus_main_widget) (CompEditorPage *page);
- void (* fill_widgets) (CompEditorPage *page, CalComponent *comp);
- gboolean (* fill_component) (CompEditorPage *page, CalComponent *comp);
+ void (* fill_widgets) (CompEditorPage *page, ECalComponent *comp);
+ gboolean (* fill_component) (CompEditorPage *page, ECalComponent *comp);
void (* set_summary) (CompEditorPage *page, const char *summary);
void (* set_dates) (CompEditorPage *page, CompEditorPageDates *dates);
@@ -84,11 +84,11 @@ GtkType comp_editor_page_get_type (void);
GtkWidget *comp_editor_page_get_widget (CompEditorPage *page);
void comp_editor_page_focus_main_widget (CompEditorPage *page);
void comp_editor_page_fill_widgets (CompEditorPage *page,
- CalComponent *comp);
+ ECalComponent *comp);
gboolean comp_editor_page_fill_component (CompEditorPage *page,
- CalComponent *comp);
-void comp_editor_page_set_cal_client (CompEditorPage *page,
- CalClient *client);
+ ECalComponent *comp);
+void comp_editor_page_set_e_cal (CompEditorPage *page,
+ ECal *client);
void comp_editor_page_set_summary (CompEditorPage *page,
const char *summary);
void comp_editor_page_set_dates (CompEditorPage *page,